from tfads_o_builder.feature_types._Base import _Base


class ObstructionHeightAGL(_Base):
    def __init__(self):
        super().__init__()
        self.field_name = "Obstruction Height AGL"
        self.note = "In Feet"



from tfads_o_builder.feature_types._Base import _Base


class FACCName(_Base):
    name_list = [
        "AERIAL CABLE",
        "AMUS PARK STR",
        "ARCH",
        "BUILDING",
        "BUILDING (HANGAR)",
        "COOLING TOWER",
        "CONDUIT",
        "CRANE",
        "DAM",
        "INDUS PLANT",
        "INDUS STRUCTURE",
        "LIGHTHOUSE",
        "LIGHTSHIP",
        "MINING STRUCTURE",
        "MISC NATURAL",
        "MISC MAN-MADE",
        "OPEN STORAGE",
        "PLATFORM",
        "PYLON",
        "PYRAMID",
        "RADAR ANTENNA",
        "SHIP STORAGE",
        "SIGN",
        "SKI JUMP",
        "SMOKESTACK",
        "STADIUM",
        "STORAGE STRUC",
        "TETHERED BALLOON",
        "TANK",
        "TRAN STRUCTURE",
        "TOWER",
        "WASTE PILE",
        "WINDMILL",
    ]

    def __init__(self):
        super().__init__()
        self.field_name = "FACC Name"

    def validateValue(self):
        # If the value is not None then assert that it is in the name list
        if self.value is not None:
            assert (
                self.value in self.name_list
            ), f"The value {self.value} must be in the FACC name list {self.name_list}."



from tfads_o_builder.feature_types._Base import _Base


class TransactionType(_Base):
    code_list = ["D", "N", "R", "S", "V", "X"]

    def __init__(self):
        super().__init__()
        self.field_name = "Transaction Type / Code"

    def validateValue(self):
        # If the value is not None then assert that it is in the code list
        if self.value is not None:
            assert (
                self.value in self.code_list
            ), f"The value {self.value} must be in the Transaction Type / Code list {self.code_list}."



from tfads_o_builder.feature_types._Base import _Base


class PreviousVOIdentifierCode(_Base):
    def __init__(self):
        super().__init__()
        self.field_name = "Previous VO Identifier Code"



from tfads_o_builder.feature_types._Base import _Base


class ProvinceCode(_Base):
    code_list = [
        1,
        2,
        4,
        5,
        6,
        8,
        9,
        10,
        11,
        12,
        13,
        15,
        16,
        17,
        18,
        19,
        20,
        21,
        22,
        23,
        24,
        25,
        26,
        27,
        28,
        29,
        30,
        31,
        32,
        33,
        34,
        35,
        36,
        37,
        38,
        39,
        40,
        41,
        42,
        44,
        45,
        46,
        47,
        48,
        49,
        50,
        51,
        53,
        54,
        55,
        56,
    ]

    def __init__(self):
        super().__init__()
        self.field_name = "Province Code"

    def validateValue(self):
        # If the value is not None then assert that it is in the code list
        if self.value is not None:
            assert (
                self.value in self.code_list
            ), f"The value {self.value} must be in the Province Code list {self.code_list}."



from tfads_o_builder.feature_types._Base import _Base
import re


# "f47ac10b-58cc-4372-a567-0e02b2c3d479",
# "f47ac10b-58cc-4372-a567-0e02b2c3d4791",
# "f47ac10b58cc4372a5670e02b2c3d479",
# "12345678-1234-1234-1234-123456789012"
class UUID(_Base):
    def __init__(self):
        super().__init__()
        self.field_name = "UUID"
        self.note = "UUID consists of 32 hexadecimal digits, displayed in 5 groups separated by hyphens, in the form 8-4-4-4-12 for a total of 36 characters (32 digits and 4 hyphens)."

    def validateValue(self):
        # If the value is not None then assert
        if self.value is not None:
            # Regular expression pattern for UUID matching
            pattern = r"^[0-9a-f]{8}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{4}-[0-9a-f]{12}$"

            # Check if the string matches the pattern
            assert re.match(pattern, self.value), f"{self.value} is not a valid UUID."



from tfads_o_builder.feature_types._Base import _Base


class FeatureTypeName(_Base):
    name_list = [
        "Aerial Cable",
        "Amus Park Str",
        "Arch",
        "Building",
        "Building (Hangar)",
        "Bridge",
        "Cooling Tower",
        "Conduit",
        "Crane",
        "Dam",
        "Indus Plant",
        "Indus Structure",
        "Lightship",
        "Lighthouse",
        "Mining Structure",
        "Misc Man-Made",
        "Misc Natural",
        "Open Storage",
        "Platform",
        "Pylon",
        "Pyramid",
        "Radar Antenna",
        "Ship Storage",
        "Sign",
        "Ski Jump",
        "Smokestack",
        "Stadium",
        "Storage Struc",
        "Tank",
        "Tethered Balloon",
        "Tower",
        "Tran Structure",
        "Waste Pile",
        "Windmill",
    ]

    def __init__(self):
        super().__init__()
        self.field_name = "Feature Type Name"

    def validateValue(self):
        # If the value is not None then assert that it is in the name list
        if self.value is not None:
            assert (
                self.value in self.name_list
            ), f"The value {self.value} must be in the FACC name list {self.name_list}."
